#! /bin/bash

PACKAGE_NAME="printer-driver-bisheng-canon-ir2318-2320-ufrii-lt"
PACKAGE_VERSION="2.0.1"
PRINTER_NAME=( "Canon iR2318-2320 UFRII LT" "Canon iR2420 UFRII LT" "Canon iR2520 UFRII LT" "Canon iR2002-2202 UFRII LT" "Canon iR2422 UFRII LT" "Canon iR2525-2530 UFRII LT" "Canon iR1133 UFRII LT" "Canon iR1435 UFRII LT" "Canon iR2535-2545 UFRII LT" "Canon iR1730-1740-1750 UFRII LT" "Canon iR C1028-1030 UFRII LT" "Canon iR-ADV 4025-4035 UFR II" "Canon iR-ADV 4225-4235 UFR II" "Canon iR-ADV 400-500 UFR II" "Canon iR-ADV 4045-4051 UFR II" "Canon iR-ADV 4245-4251 UFR II" "Canon iR-ADV 6055-6065 UFR II" "Canon iR-ADV 6255-6265 UFR II" "Canon iR-ADV 6075 UFR II" "Canon iR-ADV 6275 UFR II" "Canon iR-ADV 8085-8095 UFR II" "Canon iR-ADV 8285-8295 UFR II" "Canon iR-ADV 8105 UFR II" "Canon iR-ADV 8205 UFR II" "Canon iR-ADV C3320 UFR II" "Canon iR-ADV C3320L UFR II" "Canon iR-ADV C2025 UFR II" "Canon iR-ADV C2225 UFR II" "Canon iR-ADV C2020-2030 UFR II" "Canon iR-ADV C2220-2230 UFR II" "Canon iR-ADV C3325-3330 UFR II" "Canon iR-ADV C250-350 UFR II" "Canon iR-ADV C351 UFR II" "Canon iR-ADV C5030-5035 UFR II" "Canon iR-ADV C5235-5240 UFR II" "Canon iR-ADV C5045-5051 UFR II" "Canon iR-ADV C5250-5255 UFR II" "Canon iR-ADV C7055-7065 UFR II" "Canon iR-ADV C7260-7270 UFR II" "Canon iR-ADV C9060-9070 UFR II" "Canon iR-ADV C9065-9075 UFR II" "Canon iR-ADV C7280 UFR II" "Canon iR-ADV C9270-9280 UFR II" "Canon iPR C600 UFR II" "Canon iPR C6010 UFR II" "Canon iPR C6010VP UFR II" "Canon iPR C7010VP UFR II" "Canon iPR C700-800 UFR II" "Canon MF620C Series UFRII LT" "Canon MF720C Series UFRII LT" "Canon MF9200 Series UFRII LT" "Canon MF810-820 UFR II" "Canon LBP8750 UFR II" "Canon LBP6650-3470 UFR II" "Canon LBP6670 UFR II" "Canon LBP6680-3480 UFR II" "Canon LBP6750-3560 UFR II" "Canon LBP8780 UFR II" "Canon LBP6780-3580 UFR II" "Canon LBP7660C UFR II" "Canon LBP7680C-5280 UFR II" "Canon LBP7780C-5480 UFR II" )

CONTAINER_PATH="$HOME/.deepinwine/$PACKAGE_NAME"
OPT_PATH="/opt/deepinwine/printer_drv/$PACKAGE_NAME"
WINEBIN="bisheng"
REGDIR="reg"
FILEDIR="files"

PRINTER_C=$1
found=0
for name in "${PRINTER_NAME[@]}"; do
    if [ "$PRINTER_C" = "$name" ]; then
        found=1
        break
    fi
done

if [ $found -eq 0 ]; then
    echo "printer $PRINTER_C not found"
    exit 0
fi

if [ -z "$PACKAGE_NAME" -o ! -d "$OPT_PATH" ]; then
    exit 1
fi

if [ -d "$CONTAINER_PATH" ]; then
    # compare version
    if [ ! -f "$CONTAINER_PATH/VERSION" ] || [ "$(cat "$CONTAINER_PATH/VERSION")" != "$PACKAGE_VERSION" ]; then
        rm -rf "$CONTAINER_PATH"
    fi
fi

WININI="$CONTAINER_PATH/drive_c/windows/win.ini"
if [ -f  $WININI ]; then
    grep -q "^$PRINTER_C=winerp.drv,USB" "$WININI" && exit 0
fi

if [ -d "$OPT_PATH/$REGDIR" ]; then
    find "$OPT_PATH/$REGDIR" -type f -regex ".*\.reg" | while read file; do
        WINEPREFIX=$CONTAINER_PATH $WINEBIN regedit "$file"
    done
fi

if [ -d "$OPT_PATH/$FILEDIR" ]; then
    find "$OPT_PATH/$FILEDIR" -not -type d | while read file; do
        path="$CONTAINER_PATH/drive_c/${file#*$FILEDIR/}"
        dir="${path%/*}"
        mkdir -p "$dir"
        cp -d "$file" "$path"
    done
fi

if [ -f "$WININI" ]; then
    grep -q "^\[devices\]" "$WININI" || sed -i -e "$ a [devices]" "$WININI"
    grep -q "^\[PrinterPorts\]" "$WININI" || sed -i -e "$ a [PrinterPorts]" "$WININI"
    sed -i -e "/^\[devices\]/a $PRINTER_C=winerp.drv,USB" "$WININI"
    sed -i -e "/^\[PrinterPorts\]/a $PRINTER_C=winerp.drv,USB,15,45" "$WININI"
fi

WINESERVER_RUNNING=1
WINESERVER_FINDNUM=0
while [ $WINESERVER_RUNNING -eq 1 ]
do
        WINESERVER_PATH=`ps -aux|grep wineserver|grep -v grep`
        if [ "$WINESERVER_PATH" = "" ] || [ $WINESERVER_FINDNUM -eq 3 ]; then
                WINESERVER_RUNNING=0
        else
                let WINESERVER_FINDNUM+=1
                sleep 1
        fi
done

echo "$PACKAGE_VERSION" > "$CONTAINER_PATH/VERSION"
echo "$PRINTER_NAME" > "$CONTAINER_PATH/name.log"
